==> bls_signature_aggregator-0.2.6.crate: bls_signature_aggregator-0.2.6/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.6](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.5...v0.2.6) (2021-06-01)

### [0.2.5](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.4...v0.2.5) (2021-03-03)

### [0.2.4](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.3...v0.2.4) (2021-03-01)

### [0.2.3](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.2...v0.2.3) (2021-02-25)

### [0.2.2](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.1...v0.2.2) (2021-02-09)

### [0.2.1](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.0...v0.2.1) (2021-02-04)

## [0.2.0](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.7...v0.2.0) (2021-02-04)


### ⚠ BREAKING CHANGES

* rename AccumulationError to Error
* make the crate serialization format agnostic + remove fake clock

### Features

* make the crate serialization format agnostic + remove fake clock ([0c0b7ab](https://github.com/maidsafe/bls_signature_aggregator/commit/0c0b7ab96bfae28381109ce8ba83a13483db54ee))


* rename AccumulationError to Error ([1530822](https://github.com/maidsafe/bls_signature_aggregator/commit/1530822e4410849e93ce1b9d3e4f81d56f6d2551))

### [0.1.7](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.6...v0.1.7) (2021-02-03)

### [0.1.6](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.5...v0.1.6) (2021-01-14)

### [0.1.5](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.4...v0.1.5) (2020-11-19)

### [0.1.4](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.3...v0.1.4) (2020-10-07)

### [0.1.3](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.2...v0.1.3) (2020-10-06)

### [0.1.2](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.1...v0.1.2) (2020-09-30)

### [0.1.1](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.0...v0.1.1) (2020-09-21)

### [0.1.0](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.0...v0.1.0) (2020-08-27)
* Initial implementation

==> bls_signature_aggregator-0.2.7.crate: bls_signature_aggregator-0.2.7/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.2.7](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.6...v0.2.7) (2021-06-14)

### [0.2.6](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.5...v0.2.6) (2021-06-01)

### [0.2.5](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.4...v0.2.5) (2021-03-03)

### [0.2.4](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.3...v0.2.4) (2021-03-01)

### [0.2.3](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.2...v0.2.3) (2021-02-25)

### [0.2.2](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.1...v0.2.2) (2021-02-09)

### [0.2.1](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.2.0...v0.2.1) (2021-02-04)

## [0.2.0](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.7...v0.2.0) (2021-02-04)


### ⚠ BREAKING CHANGES

* rename AccumulationError to Error
* make the crate serialization format agnostic + remove fake clock

### Features

* make the crate serialization format agnostic + remove fake clock ([0c0b7ab](https://github.com/maidsafe/bls_signature_aggregator/commit/0c0b7ab96bfae28381109ce8ba83a13483db54ee))


* rename AccumulationError to Error ([1530822](https://github.com/maidsafe/bls_signature_aggregator/commit/1530822e4410849e93ce1b9d3e4f81d56f6d2551))

### [0.1.7](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.6...v0.1.7) (2021-02-03)

### [0.1.6](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.5...v0.1.6) (2021-01-14)

### [0.1.5](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.4...v0.1.5) (2020-11-19)

### [0.1.4](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.3...v0.1.4) (2020-10-07)

### [0.1.3](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.2...v0.1.3) (2020-10-06)

### [0.1.2](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.1...v0.1.2) (2020-09-30)

### [0.1.1](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.0...v0.1.1) (2020-09-21)

### [0.1.0](https://github.com/maidsafe/bls_signature_aggregator/compare/v0.1.0...v0.1.0) (2020-08-27)
* Initial implementation
